from ._eigengame import PLSEigenGame, CCAEigenGame, RCCAEigenGame
from ._ghagep import PLSGHAGEP, CCAGHAGEP, RCCAGHAGEP
#from ._stochasticpls import PLSStochasticPower

__all__ = [
    #"PLSStochasticPower",
    "PLSGHAGEP",
    "CCAGHAGEP",
    "RCCAGHAGEP",
    "PLSEigenGame",
    "CCAEigenGame",
    "RCCAEigenGame",
]
